@@ -1,4 +1,4 @@
-from email import message
+from time import sleep
 from typing import Any, List, Tuple
 import logging
 
@@ -236,6 +236,7 @@ class Simulator:
                 winner = self.check_if_game_over()
                 if winner[0]:
                     self.logger.info(f"Player {winner[1]} wins!")
+                sleep(1)
             except InvalidMovesException as ex:
                 self.logger.error(f"Invalid response received from player: {player}. Message: {ex.message}")
                 raise InvalidMovesException(reason=ex.reason, player=player)  # append player info to exception
